@@ -30,7 +30,7 @@ FindOptionTemplate templates[] = {
 				"Empty file" },
 	{ FIND_OPTION_CHECKBOX_TRUE, "-nouser -o -nogroup",
 				"Invalid user or group" },
-	{ FIND_OPTION_TEXT, "-not -name '%s'", "Filenames except" },
+	{ FIND_OPTION_TEXT, "\\! -name '%s'", "Filenames except" },
 	{ FIND_OPTION_GREP, "fgrep -l '%s'", "Simple substring search" },
 	{ FIND_OPTION_GREP, "grep -l '%s'", "Regular expression search" },
 	{ FIND_OPTION_GREP, "egrep -l '%s'",
@@ -39,7 +39,7 @@ FindOptionTemplate templates[] = {
 };
 
 /*this will not include the directories in search*/
-char defoptions[]="-not -type d";
+char defoptions[]="\\! -type d";
 /*this should be done if the above is made optional*/
 /*char defoptions[]="-mindepth 0";*/
 
@@ -93,6 +93,7 @@ makecmd(void)
 			case FIND_OPTION_GREP:
 				g_warning("grep options found in find list bad bad!");
 				break;
+			default:
 			}
 		}
 	}
@@ -147,6 +148,7 @@ makecmd(void)
 			case FIND_OPTION_GREP:
 				g_warning("grep options found in find list bad bad!");
 				break;
+			default:
 			}
 		}
 	}
@@ -281,9 +283,6 @@ make_list_of_templates(void)
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GSList *group=NULL;
-
-	gchar buf[50];
-
 	gint i;
 
 	menu = gtk_menu_new ();
@@ -379,6 +378,7 @@ set_option_defaults(FindOption *opt)
 	case FIND_OPTION_TIME:
 		opt->data.time=empty_str;
 		break;
+	default:
 	}
 }
 
@@ -402,7 +402,7 @@ create_option_box(FindOption *opt)
 						templates[opt->templ].desc);
 		gtk_signal_connect(GTK_OBJECT(option),"toggled",
 				   GTK_SIGNAL_FUNC(bool_changed),opt);
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(option),TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(option),TRUE);
 		break;
 	case FIND_OPTION_CHECKBOX_FALSE:
 		option = gtk_check_button_new_with_label(
@@ -422,6 +422,7 @@ create_option_box(FindOption *opt)
 				   GTK_SIGNAL_FUNC(entry_changed),opt);
 		gtk_box_pack_start(GTK_BOX(option),w,TRUE,TRUE,0);
 		break;
+	default:
 	}
 	gtk_container_add(GTK_CONTAINER(frame),option);
 
@@ -429,7 +430,7 @@ create_option_box(FindOption *opt)
 	gtk_object_set_user_data(GTK_OBJECT(w),frame);
 	gtk_signal_connect(GTK_OBJECT(w),"toggled",
 			   GTK_SIGNAL_FUNC(enable_option),opt);
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(w),TRUE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w),TRUE);
 	gtk_box_pack_start(GTK_BOX(hbox),w,FALSE,FALSE,0);
 
 	w = gtk_button_new_with_label("Remove");
@@ -528,11 +529,13 @@ create_find_page(void)
 	return vbox;
 }
 
+#ifdef NEED_UNUSED_FUNCTION
 static GtkWidget *
 create_locate_page(void)
 {
 	return gtk_label_new(_("This is not yet implemented"));
 }
+#endif
 
 static GtkWidget *
 create_window(void)
@@ -577,31 +580,21 @@ quit_cb (GtkWidget *widget, gpointer data)
 }
 
 
-
 static GnomeUIInfo file_menu[] = {
-	{GNOME_APP_UI_ITEM, N_("E_xit"), NULL, quit_cb, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL},
-	{GNOME_APP_UI_ENDOFINFO}
+	GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb,NULL),
+	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo help_menu[] = {  
-	{ GNOME_APP_UI_HELP, NULL, NULL, "gsearchtool", NULL, NULL,
-		GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}, 
-	
-	{GNOME_APP_UI_ITEM, N_("_About..."), NULL, about_cb, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
-	
-	{GNOME_APP_UI_ENDOFINFO}
+	GNOMEUIINFO_HELP("gsearchtool"),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,NULL),
+	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gsearch_menu[] = {
-	{GNOME_APP_UI_SUBTREE, N_("_File"), NULL, file_menu, NULL, NULL,
-		GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-	
-	{GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, help_menu, NULL, NULL,
-		GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-	
-	{GNOME_APP_UI_ENDOFINFO}
+	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
+        GNOMEUIINFO_END
 };
 
 
@@ -627,7 +620,6 @@ main(int argc, char *argv[])
 
 	/*set up the menu*/
         gnome_app_create_menus(GNOME_APP(app), gsearch_menu);
-	gtk_menu_item_right_justify(GTK_MENU_ITEM(gsearch_menu[1].widget));
 
 	search = create_window();
 	gtk_widget_show_all(search);
