@@ -71,7 +71,6 @@ static void close_cb(GtkWidget * w, gpointer data);
 static void save_as_cb(GtkWidget * w, gpointer data);
 static void exit_cb(GtkWidget * w, gpointer data);
 static void new_app_cb(GtkWidget * w, gpointer data);
-static void preferences_cb(GtkWidget *w, gpointer data);
 static void fixed_cb(GtkWidget * w, gpointer data);
 
 /***********************************
@@ -178,10 +177,6 @@ session_save_state (GnomeClient *client, gint phase,
   printf("\n"); fflush(stdout);
 #endif
 
-  if (shutdown) {
-    gless_exit();
-  }
-
   tmp = free_me;
   while (tmp) {
     g_free(tmp->data);
@@ -274,65 +269,42 @@ int main ( int argc, char ** argv )
   ******************************/
 
 static GnomeUIInfo help_menu[] = {
-  GNOMEUIINFO_HELP(APPNAME),
-  {GNOME_APP_UI_ITEM, N_("_About..."), 
-   N_("Tell about this application"), 
-   about_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
-  GNOMEUIINFO_END
+	GNOMEUIINFO_HELP(APPNAME),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,NULL),
+	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo file_menu[] = {
-  {GNOME_APP_UI_ITEM, 
-   N_("_New Window"), N_("New text viewer window"), 
-   new_app_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', 
-   GDK_CONTROL_MASK, NULL },
-  {GNOME_APP_UI_ITEM, 
-   N_("_Open..."), N_("Open a new file in this window"), 
-   open_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 'o', 
-   GDK_CONTROL_MASK, NULL },
-  {GNOME_APP_UI_ITEM, 
-   N_("Save _As..."), N_("Save file to disk"), 
-   save_as_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 's', 
-   GDK_CONTROL_MASK, NULL },
-  {GNOME_APP_UI_ITEM, N_("_Close"), 
-   N_("Close this window"),
-   close_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'c', 
-   GDK_CONTROL_MASK, NULL },
-  GNOMEUIINFO_SEPARATOR,
-#if 0
-  {GNOME_APP_UI_ITEM, N_("_Preferences..."), 
-   N_("Change application preferences"),
-   preferences_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 'p', 
-   GDK_CONTROL_MASK, NULL },
-#endif
-  {GNOME_APP_UI_ITEM, N_("E_xit"), 
-   N_("Quit the application"),
-   exit_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', 
-   GDK_CONTROL_MASK, NULL },
-  GNOMEUIINFO_END
+	GNOMEUIINFO_MENU_NEW_ITEM(N_("_New Window"),
+				  N_("New text viewer window"), 
+				  new_app_cb, NULL),
+	GNOMEUIINFO_MENU_OPEN_ITEM(open_cb,NULL),
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM(save_as_cb,NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_CLOSE_ITEM(close_cb,NULL),
+	GNOMEUIINFO_MENU_EXIT_ITEM(exit_cb,NULL),
+	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo view_menu[] = {
-  {GNOME_APP_UI_TOGGLEITEM, N_("_Fixed Font"), 
-   N_("Display text with a fixed font"),
-   fixed_cb, NULL, NULL,
-   0, 0, 'f', 
-   GDK_CONTROL_MASK, NULL },
-  GNOMEUIINFO_END
+
+static GnomeUIInfo settings_menu[] = {
+	{GNOME_APP_UI_TOGGLEITEM, N_("_Fixed Font"), 
+		N_("Display text with a fixed font"),
+		fixed_cb, NULL, NULL,
+		0, 0, 'f', 
+		GDK_CONTROL_MASK, NULL },
+#if 0
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cb,NULL),
+	GNOMEUIINFO_SEPARATOR,
+#endif
+	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo main_menu[] = {
-  GNOMEUIINFO_SUBTREE (N_("_File"), file_menu),
-  GNOMEUIINFO_SUBTREE (N_("_View"), view_menu),
-  GNOMEUIINFO_SUBTREE (N_("_Help"), help_menu),
-  GNOMEUIINFO_END
+	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+	GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
+	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
+	GNOMEUIINFO_END
 };
 
 static void gless_new_app(const gchar * filename, const gchar * geometry,
@@ -347,7 +319,7 @@ static void gless_new_app(const gchar * filename, const gchar * geometry,
   app = g_new(GnomeLessApp, 1);
 
   app->app = gnome_app_new( APPNAME, _("Text File Viewer") ); 
-  app->appbar = GNOME_APPBAR(gnome_appbar_new(TRUE, TRUE, 
+  app->appbar = GNOME_APPBAR(gnome_appbar_new(FALSE, TRUE, 
                                               GNOME_PREFERENCES_USER));
   gnome_app_set_statusbar(GNOME_APP(app->app), GTK_WIDGET(app->appbar));
 
@@ -376,6 +348,8 @@ static void gless_new_app(const gchar * filename, const gchar * geometry,
 
   gnome_app_create_menus_with_data(GNOME_APP(app->app), main_menu, app);
 
+  gnome_app_install_menu_hints(GNOME_APP(app->app), main_menu);
+
   app_box = gtk_vbox_new ( FALSE, GNOME_PAD );
   gtk_container_border_width(GTK_CONTAINER(app_box), GNOME_PAD);
 
@@ -701,11 +675,12 @@ static void open_cb(GtkWidget * w, gpointer data)
   gless_app_open((GnomeLessApp *)data);
 }
 
-
+#ifdef NEED_UNUSED_FUNCTION
 static void preferences_cb(GtkWidget *w, gpointer data)
 {
   gnome_ok_dialog("Sorry, no preferences yet.");
 }
+#endif
 
 static void exit_cb(GtkWidget * w, gpointer data)
 {
